@@ -1,6 +1,8 @@
 import datetime
 import pytz
 
+TORONTO = pytz.timezone("America/Toronto")
+
 def parse_datetime(timestamp: str) -> datetime.datetime:
     """
     Convert a datetime string from the TDSB API to a Python datetime.
@@ -10,6 +12,6 @@ def parse_datetime(timestamp: str) -> datetime.datetime:
     if timestamp.endswith("Z"):
         return datetime.datetime.strptime(timestamp, "%Y-%m-%dT%H:%M:%S").replace(tzinfo=datetime.timezone.utc)
     try:
-        return datetime.datetime.strptime(timestamp, "%Y-%m-%dT%H:%M:%S").replace(tzinfo=pytz.timezone("America/Toronto"))
+        return TORONTO.localize(datetime.datetime.strptime(timestamp, "%Y-%m-%dT%H:%M:%S"))
     except ValueError:
         return datetime.datetime.strptime(timestamp, "%Y-%m-%dT%H:%M:%S%z")
